#

##

    	guarantees

    		possibilities

    			--

    				the determination of the team was
    				that this food is vegan.

    				this is because of the following reasons.

    				one, the team indentified the ingredients
    				of the food to be from vegan sources.

    				two, the distributor of the food labelled
    				the food as vegan or plant based.

    				it is always possible that these labels
    				are not 100% accurate, however in the
    				interest of widespread adoption
    				of vegan, plant, and fungi based food consumption patterns,
    				we strive to please those who are striving
    				to bring the vegan food to non-vegan food consumption ratio
    				as high as possible.  we believe that this is
    				achieved through trust and leniency towards
    				distributors who claim to be distributing vegan goods.

    				essentailly we seek to get our nutrients
    				from sources, that based on biological
    				observation, feel the least amount
    				of pain and have the least intricate
    				observable structures for conscious awareness.

    				our sincere apologies in advance for any
    				lacking in perfectionism.

    			--

    				[smiley face] externally guaranteed either "plant based" or "vegan"
    					"smiley face", 'externally guaranteed either "plant based" or "vegan"'
    			--

    				[caution] produced on machinery that also produces non-plant products
    					"caution", 'produced on machinery that also produces non-plant products'